@@ -2,10 +2,13 @@
 Methods that execute specific queries against the SQLite database for the CONDITIONS table.
 This supports the policy_sentry query functionality
 """
+import logging
 from policy_sentry.shared.iam_data import get_service_prefix_data
 from policy_sentry.util.conditions import is_condition_key_match
 from policy_sentry.querying.actions import get_action_data
 
+logger = logging.getLogger(__name__)
+
 
 def get_condition_keys_for_service(service_prefix):
     """
