@@ -1,12 +1,14 @@
 """Used for loading the IAM data"""
 import os
 import json
+import logging
 
 # On initialization, load the IAM data
 iam_definition_path = os.path.join(
     os.path.abspath(os.path.dirname(__file__)), "data", "iam-definition.json"
 )
 iam_definition = json.load(open(iam_definition_path, "r"))
+logger = logging.getLogger(__name__)
 
 
 def get_service_prefix_data(service_prefix):
@@ -17,4 +19,7 @@ def get_service_prefix_data(service_prefix):
     :return:
     """
     result = list(filter(lambda item: item["prefix"] == service_prefix, iam_definition))
-    return result[0]
+    try:
+        return result[0]
+    except IndexError as i_e:
+        logger.info("Service prefix not found. See error: %s", str(i_e))
